/**
 * Check if a value is a column reference node.
 * @param {*} value The value to check.
 * @returns {value is ColumnRefNode}
 */
export function isColumnRef(value: any): value is ColumnRefNode;
export class ColumnRefNode extends ExprNode {
    /**
     * Instantiate a column reference node.
     * @param {TableRefNode} [table] The table reference.
     */
    constructor(type: any, table?: TableRefNode);
    /**
     * The table reference.
     * @type {TableRefNode}
     * @readonly
     */
    readonly table: TableRefNode;
    /**
     * Returns the column name.
     * @returns {string}
     */
    get column(): string;
}
export class ColumnNameRefNode extends ColumnRefNode {
    /**
     * Instantiate a column reference node.
     * @param {string} name The column name.
     * @param {TableRefNode} [table] The table reference.
     */
    constructor(name: string, table?: TableRefNode);
    /**
     * The column name.
     * @type {string}
     * @readonly
     */
    readonly name: string;
}
import { ExprNode } from './node.js';
import type { TableRefNode } from './table-ref.js';
