export class WithClauseNode extends SQLNode {
    /**
     * Instantiate a with clause node for a common table expression (CTE).
     * @param {string} name The common table expression (CTE) name.
     * @param {Query} query The common table expression (CTE) query.
     * @param {boolean | null} [materialized] The common table expression (CTE)
     *  materialization flag. If `true`, forces materialization of the CTE.
     *  If `false`, materialization is not performed. Otherwise (for example, if
     *  `undefined` or `null`), materialization is decided by the database.
     */
    constructor(name: string, query: Query, materialized?: boolean | null);
    /**
     * The common table expression (CTE) name.
     * @type {string}
     * @readonly
     */
    readonly name: string;
    /**
     * The common table expression (CTE) query.
     * @type {Query}
     * @readonly
     */
    readonly query: Query;
    /**
     * The common table expression (CTE) materialization flag.
     * @type {boolean | null}
     * @readonly
     */
    readonly materialized: boolean | null;
}
import { SQLNode } from './node.js';
import type { Query } from './query.js';
