/**
 * Return true if the floating point value is not a number, false otherwise.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function isNaN(expr: ExprValue): FunctionNode;
/**
 * Return true if the floating point value is finite, false otherwise.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function isFinite(expr: ExprValue): FunctionNode;
/**
 * Return true if the floating point value is infinite, false otherwise.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function isInfinite(expr: ExprValue): FunctionNode;
/**
 * Selects the largest value.
 * @param {...ExprValue} expr The input expressions.
 * @returns {FunctionNode}
 */
export function greatest(...expr: ExprValue[]): FunctionNode;
/**
 * Selects the smallest value.
 * @param {...ExprValue} expr The input expressions.
 * @returns {FunctionNode}
 */
export function least(...expr: ExprValue[]): FunctionNode;
/**
 * Compute the exponentional function `e ** expr`.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function exp(expr: ExprValue): FunctionNode;
/**
 * Compute a base 10 logarithm.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function log(expr: ExprValue): FunctionNode;
/**
 * Compute a natural logarithm.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function ln(expr: ExprValue): FunctionNode;
/**
 * Compute the sign of a number.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function sign(expr: ExprValue): FunctionNode;
/**
 * Compute the absolute value of a number.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function abs(expr: ExprValue): FunctionNode;
/**
 * Compute the square root of a number.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function sqrt(expr: ExprValue): FunctionNode;
/**
 * Rounds the number up.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function ceil(expr: ExprValue): FunctionNode;
/**
 * Rounds the number down.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function floor(expr: ExprValue): FunctionNode;
/**
 * Round to the given decimal places.
 * @param {ExprValue} expr The input number.
 * @param {ExprValue} [places] The decimal places.
 *  Negative values are allowed, to round to tens, hundreds, etc.
 *  If unspecified, defaults to zero.
 * @returns {FunctionNode}
 */
export function round(expr: ExprValue, places?: ExprValue): FunctionNode;
/**
 * Truncates the number.
 * @param {ExprValue} expr The input number.
 * @returns {FunctionNode}
 */
export function trunc(expr: ExprValue): FunctionNode;
import type { ExprValue } from '../types.js';
import type { FunctionNode } from '../ast/function.js';
