/**
 * Function that converts geometry data to GeoJSON format.
 * @param {ExprValue} expr The input expression.
 * @returns {FunctionNode}
 */
export function geojson(expr: ExprValue): FunctionNode;
/**
 * Function that returns a spatial x position (using ST_X).
 * @param {ExprValue} expr The input expression.
 * @returns {FunctionNode}
 */
export function x(expr: ExprValue): FunctionNode;
/**
 * Function that returns a spatial y position (using ST_Y).
 * @param {ExprValue} expr The input expression.
 * @returns {FunctionNode}
 */
export function y(expr: ExprValue): FunctionNode;
/**
 * Function that returns the centroid point for geometry data.
 * @param {ExprValue} expr The input expression.
 * @returns {FunctionNode}
 */
export function centroid(expr: ExprValue): FunctionNode;
/**
 * Function that returns the centroid x-coordinate for geometry data.
 * @param {ExprValue} expr The input expression.
 * @returns {FunctionNode}
 */
export function centroidX(expr: ExprValue): FunctionNode;
/**
 * Function that returns yhe centroid y-coordinate for geometry data.
 * @param {ExprValue} expr The input expression.
 * @returns {FunctionNode}
 */
export function centroidY(expr: ExprValue): FunctionNode;
import type { ExprValue } from '../types.js';
import type { FunctionNode } from '../ast/function.js';
