/**
 * Perform aggregation over a binned 2D domain. This method takes expressions
 * for the (non-truncated) x and y bin values; these expressions should be
 * in units of grid indices, but can contain fractional components. The
 * resulting query performs grouping and aggregation over the binned domain,
 * and uses a 2D integer bin index of the form (xbin + num_xbins * ybin).
 * @param {SelectQuery} q The input query. The FROM and WHERE clauses should
 *  be added to the query separately, either before or after this method.
 * @param {ExprValue} xp The x bin expression.
 * @param {ExprValue} yp The y bin expression.
 * @param {Record<string, ExprValue>} aggs Named
 *  aggregate expressions over bins.
 * @param {number} xn The number of bins along the x dimension
 * @param {string[]} groupby Group by expressions.
 * @returns {SelectQuery} The input query, with binning expressions added.
 */
export function bin2d(q: SelectQuery, xp: ExprValue, yp: ExprValue, aggs: Record<string, ExprValue>, xn: number, groupby: string[]): SelectQuery;
import type { SelectQuery } from '../ast/query.js';
import type { ExprValue } from '../types.js';
