/**
 * @typedef {object} BinDateOptions
 * @property {TimeUnit} [interval] A string indicating a time interval
 *  unit, such as 'year', 'day', or 'hour'.
 * @property {number} [step] The number of time interval steps to
 *  take, such as 2 years or 3 months.
 * @property {number} [offset] The number of bin steps (default 0) by
 *  which to offset the result.
 * @property {number} [steps] The desired number of binning steps.
 *  This value is a hint, it does not guarantee an exact number of steps.
 */
/**
 * Return a SQL expression for date/time bins.
 * @param {ExprValue} field The column or expression to bin.
 * @param {[Date|number, Date|number]} extent The min/max extent over which to bin.
 * @param {BinDateOptions} [options] Datetime binning options.
 * @returns {ExprNode}
 */
export function binDate(field: ExprValue, extent: [Date | number, Date | number], options?: BinDateOptions): ExprNode;
export type BinDateOptions = {
    /**
     * A string indicating a time interval
     * unit, such as 'year', 'day', or 'hour'.
     */
    interval?: TimeUnit;
    /**
     * The number of time interval steps to
     * take, such as 2 years or 3 months.
     */
    step?: number;
    /**
     * The number of bin steps (default 0) by
     * which to offset the result.
     */
    offset?: number;
    /**
     * The desired number of binning steps.
     * This value is a hint, it does not guarantee an exact number of steps.
     */
    steps?: number;
};
import type { ExprValue } from '../types.js';
import type { ExprNode } from '../ast/node.js';
import type { TimeUnit } from '../types.js';
