/**
 * @typedef {object} BinHistogramOptions
 * @property {number} [step] An exact binning step to use.
 * @property {number} [steps] The desired number of binning steps.
 *  This value is a hint, it does not guarantee an exact number of steps.
 * @property {number} [minstep] A minimum binning step value. No generated
 *  step can be less than this value.
 * @property {boolean} [nice] A boolean flag (default true) indicating if bin
 *  extents should be snapped to "nice" numbers such as multiples of 5 or 10.
 * @property {number} [offset] The number of bin steps (default 0) by
 *  which to offset the result.
 */
/**
 * Return a SQL expression for histogram bins.
 * @param {ExprValue} field The column or expression to bin.
 * @param {[number, number]} extent The min/max extent over which to bin.
 * @param {BinHistogramOptions} [options] Binning options.
 * @param {ReturnType<typeof scaleTransform>} [transform] Scale transforms to
 *  apply to create (potentially non-linear) binning intervals.
 * @returns {ExprNode} The resulting SQL expression
 */
export function binHistogram(field: ExprValue, extent: [number, number], options?: BinHistogramOptions, transform?: ReturnType<typeof scaleTransform>): ExprNode;
export type BinHistogramOptions = {
    /**
     * An exact binning step to use.
     */
    step?: number;
    /**
     * The desired number of binning steps.
     * This value is a hint, it does not guarantee an exact number of steps.
     */
    steps?: number;
    /**
     * A minimum binning step value. No generated
     * step can be less than this value.
     */
    minstep?: number;
    /**
     * A boolean flag (default true) indicating if bin
     * extents should be snapped to "nice" numbers such as multiples of 5 or 10.
     */
    nice?: boolean;
    /**
     * The number of bin steps (default 0) by
     * which to offset the result.
     */
    offset?: number;
};
import type { ExprValue } from '../types.js';
import { scaleTransform } from './scales.js';
import type { ExprNode } from '../ast/node.js';
